@@ -24,14 +24,14 @@ class GetArgumentParser:
         doc = """Commit Man.
 
                 Usage:
-                    main.py init 
-                    main.py commit <message>
-                    main.py reinit
-                    main.py revert <number> [-f | --force]
-                    main.py man
-                    main.py showlog
-                    main.py (-h | --help)
-                    main.py --version
+                    cm init 
+                    cm commit <message>
+                    cm reinit
+                    cm revert <number> [-f | --force]
+                    cm man
+                    cm showlog
+                    cm (-h | --help)
+                    cm --version
                 Options:
                     -h --help     Show this screen.
                     -f --force    Force
